@@ -84,6 +84,8 @@ config = {
 			"np": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"ske": { "type": "text", "analyzer": "postag_ana","fielddata":"true"},
 			"i": { "type": "integer"},
+			"start": { "type": "integer"},
+			"end": { "type": "integer"},
 			"score": { "type": "float"},
 			"offset": { "type": "float"},
 			"final_score": { "type": "float"},
@@ -106,6 +108,7 @@ config = {
 			"low": { "type": "keyword"},
 			"pos": { "type": "keyword"},
 			"tag": { "type": "keyword"},
+			"term": { "type": "keyword"},
 
 			"ap": { "type": "keyword"},
 			"page": { "type": "keyword"},
@@ -119,7 +122,6 @@ config = {
 			"tmf": { "type": "float"},
 			"stroke": { "type": "keyword", "index": "false"},
 			"strokes": { "type": "keyword", "index": "false"},
-
 			"en": { "type": "text", "analyzer": "standard","fielddata":"true"},
 			"content": { "type": "text", "analyzer": "standard","fielddata":"true"},
 			"zhseg": { "type": "text", "analyzer": "standard"},
